#include <algorithm>
#include <cassert>
#include <cstdint>
#include <iostream>
#include <ranges>
#include <vector>

constexpr int64_t MOD = 998'244'353;

int main() {
    int64_t x;
    int32_t n, m;
    std::cin >> x >> n >> m;

    // pos, isHouse
    std::vector<std::array<int64_t, 2>> pts;
    pts.reserve(n + m);
    for (int32_t i = 0; i < n + m; ++i) {
        int64_t pos;
        char type;
        std::cin >> pos >> type;

        pts.push_back({pos, type == 'H'});
    }

    assert(std::is_sorted(pts.begin(), pts.end()));

    std::vector<std::vector<int32_t>> graph(n + m);
    auto addEdge = [&](int32_t house, int32_t person) {
        assert(pts[house][1]);
        assert(!pts[person][1]);

        if (auto it = std::ranges::find(graph[house], person); it == graph[house].end()) {
            graph[house].push_back(person);
            graph[person].push_back(house);
        }
    };

    std::vector<int32_t> houseStack;
    houseStack.reserve(m);

    for (int32_t k = 0; k < 2; ++k) {
        for (int32_t i = 0; i < n + m; ++i) {
            auto [pos, isHouse] = pts[i];
            if (isHouse) {
                houseStack.push_back(i);
            } else if (!houseStack.empty()) {
                int32_t j = houseStack.back();
                houseStack.pop_back();

                addEdge(j, i);
            }
        }
    }

    houseStack.clear();
    for (int32_t k = 0; k < 2; ++k) {
        for (int32_t i = n + m - 1; i >= 0; --i) {
            auto [pos, isHouse] = pts[i];
            if (isHouse) {
                houseStack.push_back(i);
            } else if (!houseStack.empty()) {
                int32_t j = houseStack.back();
                houseStack.pop_back();

                addEdge(j, i);
            }
        }
    }

    auto dist = [&](int32_t u, int32_t v) -> int64_t {
        assert(pts[u][1] != pts[v][1]);
        int64_t d = std::abs(pts[u][0] - pts[v][0]);

        return std::min(d, x - d);
    };

    std::vector<uint8_t> vis(n + m, false);

    int64_t totalCost = 0;
    int64_t totalWays = 1;
    for (int32_t u = 0; u < n + m; ++u) {
        auto [pos, isHouse] = pts[u];
        if (!isHouse || vis[u] || graph[u].size() != 1) continue;

        std::vector<int64_t> costs;
        {
            int32_t v = u;
            while (!vis[v]) {
                vis[v] = true;
                if (auto it = std::ranges::find_if(graph[v], [&vis](auto w){ return !vis[w]; }); it != graph[v].end()) {
                    costs.push_back(dist(v, *it));
                    v = *it;
                }
            }
        }

        assert(costs.size() % 2 == 0);
        int64_t cost = 0;
        for (int32_t i = 1; i < costs.size(); i += 2) {
            cost += costs[i];
        }

        int64_t bestCost = cost;
        int64_t costWays = 1;
        for (int32_t i = 0; i + 1 < costs.size(); i += 2) {
            cost -= costs[i + 1];
            cost += costs[i];
            if (cost < bestCost) {
                bestCost = cost;
                costWays = 0;
            }

            if (cost == bestCost) {
                ++costWays;
            }
        }

        totalCost += bestCost;
        totalWays = totalWays * costWays % MOD;
    }

    std::cout << totalCost << std::endl;
    std::cout << totalWays << std::endl;

    return 0;
}
